django-require-license
======================

License header for django-require projects.

.. image:: https://img.shields.io/pypi/v/django-require-license.svg
    :target: https://pypi.python.org/pypi/django-require-license
.. image:: https://travis-ci.org/collab-project/django-require-license.svg?branch=master
    :target: https://travis-ci.org/collab-project/django-require-license
.. image:: https://coveralls.io/repos/collab-project/django-require-license/badge.svg
    :target: https://coveralls.io/r/collab-project/django-require-license
.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :target: https://raw.githubusercontent.com/collab-project/django-require-license/master/LICENSE

Installation
------------

Use pip_ to install the download and install the package from PyPi_::

  pip install django-require-license

Or checkout the source code from Github_::

  git clone https://github.com/collab-project/django-require-license.git


Documentation
-------------

Documentation can be found on `readthedocs.org`_.


.. _pip: https://pypi.python.org/pypi/pip
.. _PyPi: https://pypi.python.org/pypi/django-require-license
.. _readthedocs.org: https://django-require-license.readthedocs.org/en/latest
.. _Github: https://github.com/collab-project/django-require-license
